# Release Policy

## Versioning

- Stable tags: `vX.Y.Z`
- Pre-release tags: `vX.Y.Z-rc.N`

## Release pipeline

1. Quality gate
2. Build artifacts
3. Publish PyPI
4. Create GitHub Release
5. Publish docs on push to `main`

## Changelog

Generated from Conventional Commits and curated release notes.
